@@ -12,9 +12,10 @@ import xarray as xr
 from .Util import _correct_type
 # set font to TNR
 plt.rc('font', family='Times New Roman')
+plt.set_cmap("RdBu_r")
 
 
-def get_levels(data, percentile: int, num_level: int, zero_sym: bool) -> np.ndarray:
+def get_levels(data, percentile: int = 98, num_level: int = 13, zero_sym: bool = True) -> np.ndarray:
     """ get levels of data
 
     Args:
@@ -31,13 +32,13 @@ def get_levels(data, percentile: int, num_level: int, zero_sym: bool) -> np.ndar
         percentile = 98
     if num_level is None:
         num_level = 13
-    if zero_sym is None:
-        zero_sym = True
+    # if zero_sym is None:
+    #     zero_sym = True
     # get min and max
     _max = np.nanpercentile(data, percentile)
     _min = np.nanpercentile(data, 100 - percentile)
     if zero_sym is None:
-        if _min*_max <0:
+        if _min * _max < 0:
             zero_sym = True
         else:
             zero_sym = False
@@ -57,8 +58,8 @@ def _store_range(self, x, y):
         x (np.ndarray): x 
         y (np.ndarray): y
     """
-    x= _correct_type(x)
-    y= _correct_type(y)
+    x = _correct_type(x)
+    y = _correct_type(y)
     if x is not None:
         # save to xrange
         if not hasattr(self, "xrange"):
@@ -355,6 +356,7 @@ def _quiver(self, *args, **kwargs):
     else:
         del kwargs['stepy']
     x, y, U, V, C = _anal_args(args, clas="quiver")
+    self._store_range(x, y)
     if C is None:
         args1 = [x[::stepx], y[::stepy], U[::stepy, ::stepx], V[::stepy, ::stepx]]
     else:
